#***********************************************************************
# Licensed Material - Property of IBM
#
# 5724-R31, 5655-S30
#
# (c) Copyright IBM Corp. 2009,2010,2011.  All rights reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#************************************************************************
##################################################################
#
# Deploys Banking ICP ears.
#
# #######################################################################
import sys
import java
#########################################################################
# Load properties from file
#########################################################################
print
print "Reading configuration properties ..."
from java.util import Properties
from java.io import FileInputStream
from java.io import FileOutputStream
from java.io import OutputStreamWriter
from java.lang import System
from java.lang import Boolean
from java.lang import Integer
from java.lang import String
from java.lang import System


propFile = "config.properties"
fis = FileInputStream(propFile)
prop = Properties()
prop.load(fis)
print prop

#########################################################################
# Get Derby DB DSN properties
#########################################################################
jndiName = prop.getProperty('jndiName')
wicpDatabaseName = prop.getProperty('wicpDatabaseName')
wicpDbHostName = prop.getProperty('wicpDbHostName')
wicpDbUser = prop.getProperty('wicpDbUser')
wicpDbPassword = prop.getProperty('wicpDbPassword')



#########################################################################
# Get connected cell/node/server name
#########################################################################
print
print "Reading server configuration ..."
cell = AdminControl.getCell();
print cell
node = AdminControl.getNode();
print node
wsadminServer =AdminControl.queryNames("node=" + node + ",type=Server,*" )
server = AdminControl.getAttribute(wsadminServer, "name" )
print server
#######################################################################
#
#
#########################################################################
# Get CEI configuration options
#########################################################################
print
print "Loading CEI configurations ..."

serverLocation = prop.getProperty('serverLocation')
hostName = prop.getProperty('hostName')
rmiPort = prop.getProperty('rmiPort')
soapPort = prop.getProperty('soapPort')
securityMode = prop.getProperty('securityMode')
userid = prop.getProperty('userid')
password = prop.getProperty('password')
eventGroup = prop.getProperty('eventGroup')
cellName = prop.getProperty('cellName')
#nodeName = prop.getProperty('nodeName')
serverName = prop.getProperty('serverName')
clusterName = prop.getProperty('clusterName')
distributionMode = prop.getProperty('distributionMode')
createCubes = prop.getProperty('createCubes')
startCubes = prop.getProperty('startCubes')
businessSituation = prop.getProperty('businessSituation')
profileMigration = prop.getProperty('profileMigration')



#########################################################################
# Get User and Group properties
#########################################################################
print
print "Loading User and Group configurations ..."
groupNameAdamCustomer = prop.getProperty('groupNameAdamCustomer')
groupNameJayBankOfficer = prop.getProperty('groupNameJayBankOfficer')
groupNameSusanLOBManager = prop.getProperty('groupNameSusanLOBManager')
groupNamePeterBankManager = prop.getProperty('groupNamePeterBankManager')

userName01Adam = prop.getProperty('userName01Adam')
userName001Adam = prop.getProperty('userName001Adam')
userName02Jay = prop.getProperty('userName02Jay')
userName002Jay = prop.getProperty('userName002Jay')
surName01Smith = prop.getProperty('surName01Smith')
surName02Walk = prop.getProperty('surName02Walk')
userName03Peter = prop.getProperty('userName03Peter')
userName003Peter = prop.getProperty('userName003Peter')
surName03Henderson = prop.getProperty('surName03Henderson')
userName04Susan = prop.getProperty('userName04Susan')
userName004Susan = prop.getProperty('userName004Susan')
surName04Thomas = prop.getProperty('surName04Thomas')

#########################################################################

#########################################################################
# Creating WICP Data Source Name
#########################################################################

def createDataSource(providerId,templateDSId,name,jndiName,helperName,authAlias):
    nameAttr = ["name", name]
    jndiAttr = ["jndiName", jndiName]
    statementCacheSizeAttr = ["statementCacheSize","100"]
    helpAttr = ["datasourceHelperClassname", helperName]
    authAttr = ["authDataAlias", authAlias]
    datasourceCreateArgs = [nameAttr, jndiAttr, statementCacheSizeAttr, helpAttr, authAttr]
    return AdminConfig.create("DataSource", providerId, datasourceCreateArgs)
    AdminConfig.save()

def createUpdateWicpDataSource(providerId,templateDSId,name,jndi,datasourceHelperClassname,resourceAttrs,wicpJ2CAuth,scopeId,scope) :
    ds = findDataSource(jndi,scopeId,scope)
    if(ds == "") :
        print "Creating Datasource with JNDI Name at scope - " + scopeId
        ds = createDataSource(providerId,templateDSId,name,jndi,datasourceHelperClassname,wicpJ2CAuth)
    else :
        print "Existing Datasource found with JNDI Name " + str(jndi) + " at scope - " + scopeId
        #User would have changed dbTypes, hence removing old one.
        AdminConfig.remove(ds)
        print "Creating new Datasource with JNDI Name " + str(jndi) + " at scope - " + scopeId
        ds = createDataSource(providerId,templateDSId,name,jndi,datasourceHelperClassname,wicpJ2CAuth)
    AdminConfig.modify(ds,resourceAttrs) 
    AdminConfig.save()


##########################################################
#Get Datasources based on JNDIname and scope.
##########################################################
def findDataSource(jndiName,scopeId,scope):

    dataSourceList = AdminConfig.list("DataSource", scopeId).split(lineSeparator)
    for dsentry in dataSourceList :
        dsJndiName = AdminConfig.showAttribute(dsentry,"jndiName")
        if(dsJndiName == jndiName) :
	        provider = AdminConfig.showAttribute(dsentry,"provider")
	        provideName = AdminConfig.showAttribute(provider,"name")
	        dataSourceName = AdminConfig.showAttribute(dsentry,"name")
	        path = scope + "JDBCProvider:"+ provideName + "/DataSource:" + dataSourceName+"/"
	        dataSource = AdminConfig.getid(path)
	        if(dataSource != "") :
	            return dataSource
    return ""

##############################################################
# Get JDBC Provider Configuration
#############################################################

def getJdbcProviderConfigId(scope, providerName):
    providerConfigId = AdminConfig.getid(scope + "JDBCProvider:" + providerName + "/").splitlines()
    if (providerConfigId == ""):
        print "Did not find JDBC Provider: " + providerName
        return None
    else:
        for provider in providerConfigId:
            print "provider" +str(provider)
            return provider


def getJdbcTemplateId(templateName):
    templateList = AdminConfig.listTemplates('JDBCProvider',templateName).splitlines()
    for temp in templateList :
        return temp
###########################################################
# Prints error message on the console
###########################################################
def validationError (errorMessage) :
    sys.stderr.write(errorMessage)
    print "Exception:validationError - " + str(errorMessage)
    sys.exit()
##########################################################
#Create JAASAuthData
##########################################################

def createJAASAuthData(alias,userId,password):
    authObj = getJAASAuthData(alias)
    aliasAttr = ['alias', alias]
    useridAttr = ['userId', userId]
    passwordAttr = ['password', password]
    jaasAttrs = [aliasAttr, useridAttr, passwordAttr]
    if(len(authObj) > 1):
        #Update the values
        print "Found Alias" + str(alias)
        AdminConfig.modify(authObj,jaasAttrs)
    else :
        security = AdminConfig.getid('/Cell:'+ cellName +'/Security:/')
        #Create Auth Alias
        print "Created J2C Auth" + alias
        AdminConfig.create('JAASAuthData', security, jaasAttrs)

	AdminConfig.save()
##########################################################
#Get JASSAuthData based on Auth Alias
##########################################################

def getJAASAuthData(aliasAuth) :
    authObj = ""
    aliasidlist = AdminConfig.list("JAASAuthData").split(lineSeparator)
    for aliasid in aliasidlist:
        qualifiedaliasName = AdminConfig.showAttribute(aliasid,"alias")
        i= qualifiedaliasName.find('/')
        name=qualifiedaliasName[i+1:len(qualifiedaliasName)]
        if (name==aliasAuth):
            authObj = aliasid
            break
    return authObj



#main()

###################################################################
# Command line parameters passed in. Evaluate each of these paramters
###################################################################

nextArg = 0;
while(len(sys.argv) > nextArg) :
    param = sys.argv[nextArg]
    nextArg +=1
    value = sys.argv[nextArg]
    nextArg +=1
    if (param == "-nodeName"):
        nodeName = value
    elif (param == "-cellName"):
        cellName = value

nodeId=AdminConfig.getid("/Node:"+nodeName+"/")

if (nodeId==""):
    validationError("Node "+ nodeName + "doesn't exist")

servers = AdminConfig.list("Server", nodeId)
serversList = servers.split(lineSeparator)
serverName =  AdminConfig.showAttribute(serversList[0], "name")
serverId=AdminConfig.getid("/Node:"+nodeName+"/Server:"+serverName+"/")

if (serverId==""):
    validationError("Server "+ serverName + " doesn't exist")

#finding the server id & name
servers = AdminConfig.list("Server", nodeId)
serversList = servers.split(lineSeparator)
serverId=AdminConfig.getid("/Node:"+nodeName+"/Server:"+serverName+"/")
#finding scope
scope = "/Node:"+nodeName+"/Server:"+serverName+"/"
scopeId = serverId

wicpDB="WICP_DB"
wicpJ2CAuth = "WICP_JDBC_AUTH"

#Creating the JASSAuthData
createJAASAuthData(wicpJ2CAuth,wicpDbUser,wicpDbPassword)

newsprops = []
template ="DB2 Universal JDBC Driver Provider (XA)"
templateDSName = "DB2 Universal JDBC Driver XA"
templateDSId = AdminConfig.listTemplates("DataSource", templateDSName)
datasourceHelperClassname = "com.ibm.websphere.rsadapter.DB2UniversalDataStoreHelper"
dbnameAttr = [["name", "databaseName"], ["value", "WICPDB"], ["type", "java.lang.String"]]
dbservernameAttr = [["name", "serverName"], ["value", "localhost"], ["type", "java.lang.String"]]
portAttr = [["name", "portNumber"], ["value", 50000], ["type", "java.lang.String"]]
drivertypeAttr = [["name", "driverType"], ["value", "4"], ["type", "java.lang.Integer"]]
newsprops.append(dbnameAttr)
newsprops.append(dbservernameAttr)
newsprops.append(portAttr)
newsprops.append(drivertypeAttr)
psAttr = ["propertySet", [["resourceProperties", newsprops]]]
resourceAttrs = [psAttr]
#Get Provider Template
templateId = getJdbcTemplateId(template)

providerId = getJdbcProviderConfigId(scope,template)
print "Got providerId" + str(providerId)

#Create JDBC Provider

if((providerId == None)):
    #Create Fabric JDBC Provider.
    print "Create Fabric JDBC Provider"
    providerCreateArgs = [["name", "WICP Datasource"]]
    print "scopeId",scopeId
    print "providerCreateArgs",providerCreateArgs
    print "templateId",templateId
    providerId = AdminConfig.createUsingTemplate("JDBCProvider", scopeId, providerCreateArgs,templateId)
    print "created providerId",providerId

createUpdateWicpDataSource(providerId,templateId,wicpDB,jndiName,datasourceHelperClassname,resourceAttrs,wicpJ2CAuth,scopeId,scope)
AdminConfig.save()

#########################################################################
# Datasource creation is done.
#########################################################################

#########################################################################
# Creating user and group and their mapping
#########################################################################
print
print "Creating Users and Groups and associating them ..."
try :
        
	attrGrpCustomer = ["-cn",groupNamePeterBankManager]
	if(len(AdminTask.searchGroups(attrGrpCustomer)) > 1):
	    print "Skipping creating group " +  groupNamePeterBankManager + " as group exists"
	else :
	    AdminTask.createGroup(attrGrpCustomer)

	attrGrpUnderWriter = ["-cn",groupNameSusanLOBManager]
	if(len(AdminTask.searchGroups(attrGrpUnderWriter)) > 1):
	    print "Skipping creating group " +  groupNameSusanLOBManager + " as group exists"
	else :
	    AdminTask.createGroup(attrGrpUnderWriter)

	attrGrpAgent = ["-cn",groupNameAdamCustomer]
	if(len(AdminTask.searchGroups(attrGrpAgent)) > 1):
	    print "Skipping creating group " +  groupNameAdamCustomer + " as group exists"
	else :
	    AdminTask.createGroup(attrGrpAgent)
	
	attrGrpLoanOfficer = ["-cn",groupNameJayBankOfficer]
	if(len(AdminTask.searchGroups(attrGrpLoanOfficer)) > 1):
	    print "Skipping creating group " +  groupNameJayBankOfficer + " as group exists"
	else :
	    AdminTask.createGroup(attrGrpLoanOfficer)

	attrName1 = ["-uid",userName01Adam]
	if(len(AdminTask.searchUsers(attrName1)) > 1):
            print "Skipping creating user " +  userName01Adam + " as user exists"
	else :
	    appOptions = ["-uid", userName01Adam, "-password", "password", "-confirmPassword", "password", "-cn", userName001Adam, "-sn", surName01Smith]
	    AdminTask.createUser(appOptions)
	    attrName1 = ["-uid",userName01Adam]
	    userStr1 = AdminTask.searchUsers(attrName1)
	    groupStr = AdminTask.searchGroups(attrGrpAgent)
	    appOptions = ["-memberUniqueName", userStr1, "-groupUniqueName",groupStr]
 	    AdminTask.addMemberToGroup(appOptions)
	
	attrName2 = ["-uid",userName02Jay]
	if(len(AdminTask.searchUsers(attrName2)) > 1):
            print "Skipping creating user " +  userName02Jay + " as user exists"
	else :
	    appOptions = ["-uid", userName02Jay, "-password", "password", "-confirmPassword", "password", "-cn", userName002Jay, "-sn", surName02Walk]
	    AdminTask.createUser(appOptions)
	    attrName2 = ["-uid",userName02Jay]
	    userStr2 =  AdminTask.searchUsers(attrName2)
	    groupStr = AdminTask.searchGroups(attrGrpLoanOfficer)
	    appOptions = ["-memberUniqueName", userStr2,"-groupUniqueName",groupStr ]
 	    AdminTask.addMemberToGroup(appOptions)
	
	attrName3 = ["-uid",userName03Peter]
	if(len(AdminTask.searchUsers(attrName3)) > 1):
            print "Skipping creating user " +  userName03Peter + " as user exists"
	else :
	    appOptions = ["-uid", userName03Peter, "-password", "password", "-confirmPassword", "password", "-cn", userName003Peter, "-sn", surName03Henderson]
	    AdminTask.createUser(appOptions)
	    attrName3 = ["-uid",userName03Peter]
	    userStr3 = AdminTask.searchUsers(attrName3)
	    groupStr = AdminTask.searchGroups(attrGrpCustomer)
	    appOptions = ["-memberUniqueName", userStr3, "-groupUniqueName",groupStr]
 	    AdminTask.addMemberToGroup(appOptions)
	
	attrName4 = ["-uid",userName04Susan]
	if(len(AdminTask.searchUsers(attrName4)) > 1):
            print "Skipping creating user " +  userName04Susan + " as user exists"
	else :
	    appOptions = ["-uid", userName04Susan, "-password", "password", "-confirmPassword", "password", "-cn", userName004Susan, "-sn", surName04Thomas]
	    AdminTask.createUser(appOptions)
	    attrName4 = ["-uid",userName04Susan]
	    userStr4 = AdminTask.searchUsers(attrName4)
	    groupStr = AdminTask.searchGroups(attrGrpUnderWriter)
	    appOptions = ["-memberUniqueName", userStr4, "-groupUniqueName",groupStr]
 	    AdminTask.addMemberToGroup(appOptions)

except :
        print "Exception:Error occured while Group user creation and mapping"
        sys.stderr.write("Error occured while Group user creation and mapping")
        raise
        print "Group groupNamePeterBankManager"

#########################################################################
# Creating user and group and their mapping done
#######################################################################



# #Save configuration
#######################################################################
AdminConfig.save()
print "All the configurations are saved .."
#######################################################################
# End of file.
##########################################